import { Component, Project } from 'projen';
import { ReleaseOptions } from './release-tasks';
/**
 * Base tasks for projen projects based on
 * "common-targets" (https://github.com/flaviostutz/common-targets)
 */
export declare class CommonTargetsTasks extends Component {
    constructor(project: Project, opts?: BaseTasksOptions);
}
export interface BaseTasksOptions {
    /**
     * Whether to include the build task with all its default subtasks
     */
    readonly buildEnable?: boolean;
    /**
     * Whether to include the lint tasks
     */
    readonly lintEnable?: boolean;
    /**
     * Whether to include the test tasks
     */
    readonly testEnable?: boolean;
    /**
     * Whether to include release tasks
     */
    readonly releaseEnable?: boolean;
    /**
     * Release task options
     */
    readonly releaseOpts?: ReleaseOptions;
    /**
     * Whether to include deploy tasks
     */
    readonly deployEnable?: boolean;
    /**
     * Whether to include publish tasks
     */
    readonly publishEnable?: boolean;
    /**
     * Whether to cleanup default tasks (build, test, compile, package, pre-compile, post-compile)
     * before adding new ones
     * @default true
     */
    readonly cleanupDefaultTasks?: boolean;
}
