import { Component, Project, TaskStep } from 'projen';
import { NextTagOptions } from '../../types';
import { PublishPypiOptions } from './publish-pypi-tasks';
import { PublishNpmOptions } from './publish-npm-tasks';
/**
 * Defines a set of tasks to publish packages to npm and/or pypi registries.
 */
export declare class PublishTasks extends Component {
    constructor(project: Project, opts?: PublishOptions);
}
export declare const expandOpts: (opts?: PublishOptions) => PublishOptions;
export declare const npmWithDefaults: (opts: PublishNpmOptions) => PublishNpmOptions;
export declare const pypiWithDefaults: (opts: PublishPypiOptions) => PublishPypiOptions;
export declare const checkTaskAndFilesScript: (project: Project, taskName: string, opts: PublishOptions, packagesDir: string) => string;
export declare const prePublishSteps: (taskName: string, opts: PublishOptions, fileVersionChecksScript: string, project: Project) => TaskStep[];
export interface PublishOptions {
    /**
     * The name of the task that will be invoked to generate package files to be published.
     * @default 'build', if exists in project. If not, no build task will be invoked.
     */
    readonly buildTask?: string;
    /**
     * If true, won't bump the version field of package.json, pyproject.toml etc to the latest tag found before invoking the build task.
     * @default false
     */
    readonly skipBump?: boolean;
    /**
     * Disable checks before publishing.
     * By default the following checks are performed:
     * - The git working directory is clean (no uncommited changes)
     * - The current commit is tagged with the latest version calculated for the package
     * - The latest version tagged in git is equal to the version in the package file name being published
     * This is useful to avoid publishing packages whose contents are not actually commited/tagged in git.
     * In order to perform some of the checks, monotag will be invoked with action "current". If not, "tag" will be used.
     * @default false
     */
    readonly skipChecks?: boolean;
    /**
     * Options for next tag calculation. Used as the base options for monotag invocations during bumping and tagging checks
     */
    readonly monotagOptions?: NextTagOptions;
    /**
     * Options for npm publishing.
     */
    readonly npm?: PublishNpmOptions;
    /**
     * Options for pypi publishing.
     */
    readonly pypi?: PublishPypiOptions;
    /**
     * If defined, will suffix the task name by this name so that multiple
     * publish tasks with different configurations can be defined in the same project.
     */
    readonly group?: string;
}
